@@ -6,6 +6,7 @@ Created on Fri Jan 14 17:00:39 2022
 """
 
 #Loading Packages
+import os
 import numpy as np
 import pandas as pd
 import transformers
@@ -16,6 +17,8 @@ from transformers import pipeline
 from sentence_transformers import SentenceTransformer, util
 from sklearn.metrics.pairwise import cosine_similarity
 similarity_model = SentenceTransformer('distilbert-base-nli-stsb-mean-tokens')
+path = os.getcwd()
+os.chdir(path)
 
 #%% 
 #Classification Model
@@ -24,8 +27,9 @@ model = TFAutoModelForSequenceClassification.from_pretrained("d4data/environment
 classifier = pipeline('text-classification', model=model, tokenizer=tokenizer) # cuda = 0,1 based on gpu availability
 
 #%%
-def load_embeddings():
-    return pd.read_csv('data/embeddings.csv')
+
+def load_embeddings(path):
+    return pd.read_csv(path + '\\data\\embeddings.csv')
 
 def predict(text_input):
     #running the classification model to predict the classes
@@ -36,7 +40,7 @@ def predict(text_input):
     #running due diligence ranking module
     # due diligence ranking dictionary
     embeddings_text = np.float64(similarity_model.encode([text_input]))
-    embeddings_df = load_embeddings()
+    embeddings_df = load_embeddings(path)
     
     
     if edd_label == 'Remediation Activities':
